@@ -1,6 +1,6 @@
 package Resque;
 # ABSTRACT: Redis-backed library for creating background jobs, placing them on multiple queues, and processing them later.
-$Resque::VERSION = '0.29';
+$Resque::VERSION = '0.30';
 use Moose;
 use Scalar::Util 'blessed';
 use Moose::Util::TypeConstraints;
@@ -181,7 +181,7 @@ Resque - Redis-backed library for creating background jobs, placing them on mult
 
 =head1 VERSION
 
-version 0.29
+version 0.30
 
 =head1 SYNOPSIS
 
@@ -331,7 +331,7 @@ Given a queue name, completely deletes the queue.
 
 Given a queue name, creates an empty queue.
 
-    $r-create_queue( 'my_queue' );
+    $r->create_queue( 'my_queue' );
 
 =head2 mass_dequeue
 
