@@ -1,6 +1,6 @@
 package Resque::Failures;
 # ABSTRACT: Class for managing Resque failures
-$Resque::Failures::VERSION = '0.29';
+$Resque::Failures::VERSION = '0.30';
 use Moose;
 with 'Resque::Encoder';
 use Class::Load qw(load_class);
@@ -123,7 +123,7 @@ Resque::Failures - Class for managing Resque failures
 
 =head1 VERSION
 
-version 0.29
+version 0.30
 
 =head1 ATTRIBUTES
 
@@ -142,29 +142,43 @@ By default: Resque::Failure::Redis
 
 create() a failure on the failure_class() and save() it.
 
+$failures->throw( %job_description_hash );
+
+See L<Resque> code for a usage example.
+
 =head2 create
 
 Create a new failure on the failure_class() backend.
 
+$failures->create( ... );
+
 =head2 count
 
-How many failures was in all the resque system.
+How many failures are in the resque system.
+
+my $count = $failures->count();
 
 =head2 all
 
-Return a range of failures in the same way Resque::peek() does for
-jobs.
+Return a range of failures (or an arrayref in scalar context)
+in the same way Resque::peek() does for jobs.
+
+my @failures = $failures->all('my_queue', $opt_start, $opt_count);
 
 =head2 clear
 
 Remove all failures.
 
+$failures->clear();
+
 =head2 requeue
 
 Requeue by index number.
 
 Failure will be updated to note retried date.
 
+$failures->requeue( $index );
+
 =head2 remove
 
 Remove failure by index number in failures queue.
@@ -174,6 +188,8 @@ sucesive ones will move left, so index will decrese
 one. If you want to remove several ones start removing
 from the rightmost one.
 
+$failures->remove( $index );
+
 =head2 mass_remove
 
 Remove and optionally requeue all or matching failed jobs. Errors that happen
