@@ -1,6 +1,6 @@
 package Resque::Job;
 # ABSTRACT: Resque job container
-$Resque::Job::VERSION = '0.29';
+$Resque::Job::VERSION = '0.30';
 use Moose;
 use Moose::Util::TypeConstraints;
 with 'Resque::Encoder';
@@ -127,7 +127,7 @@ Resque::Job - Resque job container
 
 =head1 VERSION
 
-version 0.29
+version 0.30
 
 =head1 ATTRIBUTES
 
@@ -212,10 +212,10 @@ See Resque::mass_dequeue() for massive destruction.
 
 =head2 fail
 
-Store a failure (or arrayref of failures) on this job.
+Store a failure (or exception and failure) on this job.
 
     $job->fail( "error message'); # or
-    $job->fail( ['msg1', 'msg2'] );
+    $job->fail( ['exception', 'error message'] );
 
 =head1 AUTHOR
 
